summaryrefslogtreecommitdiff
path: root/src/pcre2test.c
diff options
context:
space:
mode:
authorph10 <ph10@6239d852-aaf2-0410-a92c-79f79f948069>2017-07-19 16:04:15 +0000
committerph10 <ph10@6239d852-aaf2-0410-a92c-79f79f948069>2017-07-19 16:04:15 +0000
commitf3d7f4fabd6d124ad8e323b09ebf373bfe045b4e (patch)
treec7acda8683a47a84ac28936edf7ce7a2c2b5965f /src/pcre2test.c
parent9a3717bbc462ed041a735351174a8fa96441d3b7 (diff)
downloadpcre2-f3d7f4fabd6d124ad8e323b09ebf373bfe045b4e.tar.gz
Code tidies for 10.30-RC1 release candidate.
git-svn-id: svn://vcs.exim.org/pcre2/code/trunk@842 6239d852-aaf2-0410-a92c-79f79f948069
Diffstat (limited to 'src/pcre2test.c')
-rw-r--r--src/pcre2test.c9
1 files changed, 7 insertions, 2 deletions
diff --git a/src/pcre2test.c b/src/pcre2test.c
index 3ce261c..5d1cbdc 100644
--- a/src/pcre2test.c
+++ b/src/pcre2test.c
@@ -4073,7 +4073,8 @@ else fprintf(outfile, "%s%s%s%s%s%s%s%s%s%s%s%s%s%s%s%s%s%s%s%s%s%s%s%s%s%s%s%s%
* Show compile extra options *
*************************************************/
-/* Called for unsupported POSIX options.
+/* Called only for unsupported POSIX options at present, and therefore needed
+only when the 8-bit library is being compiled.
Arguments:
options an options word
@@ -4083,17 +4084,21 @@ Arguments:
Returns: nothing
*/
+#ifdef SUPPORT_PCRE2_8
static void
show_compile_extra_options(uint32_t options, const char *before,
const char *after)
{
if (options == 0) fprintf(outfile, "%s <none>%s", before, after);
-else fprintf(outfile, "%s%s%s%s",
+else fprintf(outfile, "%s%s%s%s%s%s",
before,
((options & PCRE2_EXTRA_ALLOW_SURROGATE_ESCAPES) != 0)? " allow_surrogate_escapes" : "",
((options & PCRE2_EXTRA_BAD_ESCAPE_IS_LITERAL) != 0)? " bad_escape_is_literal" : "",
+ ((options & PCRE2_EXTRA_MATCH_WORD) != 0)? " match_word" : "",
+ ((options & PCRE2_EXTRA_MATCH_LINE) != 0)? " match_line" : "",
after);
}
+#endif